==> 0.1.2-beta.tar.gz: lib/web.dart <==
// Copyright (c) 2023, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

export 'src/dom/accelerometer.dart';
export 'src/dom/ambient_light.dart';
export 'src/dom/anchors.dart';
export 'src/dom/angle_instanced_arrays.dart';
export 'src/dom/attribution_reporting_api.dart';
export 'src/dom/audio_output.dart';
export 'src/dom/autoplay_detection.dart';
export 'src/dom/background_fetch.dart';
export 'src/dom/background_sync.dart';
export 'src/dom/badging.dart';
export 'src/dom/battery_status.dart';
export 'src/dom/beacon.dart';
export 'src/dom/capture_handle_identity.dart';
export 'src/dom/clipboard_apis.dart';
export 'src/dom/close_watcher.dart';
export 'src/dom/compat.dart';
export 'src/dom/compression.dart';
export 'src/dom/compute_pressure.dart';
export 'src/dom/console.dart';
export 'src/dom/contact_picker.dart';
export 'src/dom/content_index.dart';
export 'src/dom/cookie_store.dart';
export 'src/dom/crash_reporting.dart';
export 'src/dom/credential_management.dart';
export 'src/dom/csp.dart';
export 'src/dom/csp_embedded_enforcement.dart';
export 'src/dom/csp_next.dart';
export 'src/dom/css_animation_worklet.dart';
export 'src/dom/css_animations.dart';
export 'src/dom/css_animations_2.dart';
export 'src/dom/css_cascade.dart';
export 'src/dom/css_cascade_6.dart';
export 'src/dom/css_color_5.dart';
export 'src/dom/css_conditional.dart';
export 'src/dom/css_contain.dart';
export 'src/dom/css_contain_3.dart';
export 'src/dom/css_counter_styles.dart';
export 'src/dom/css_font_loading.dart';
export 'src/dom/css_fonts.dart';
export 'src/dom/css_highlight_api.dart';
export 'src/dom/css_images_4.dart';
export 'src/dom/css_layout_api.dart';
export 'src/dom/css_masking.dart';
export 'src/dom/css_nav.dart';
export 'src/dom/css_nesting.dart';
export 'src/dom/css_paint_api.dart';
export 'src/dom/css_parser_api.dart';
export 'src/dom/css_properties_values_api.dart';
export 'src/dom/css_pseudo.dart';
export 'src/dom/css_regions.dart';
export 'src/dom/css_shadow_parts.dart';
export 'src/dom/css_transitions.dart';
export 'src/dom/css_transitions_2.dart';
export 'src/dom/css_typed_om.dart';
export 'src/dom/css_view_transitions.dart';
export 'src/dom/cssom.dart';
export 'src/dom/cssom_view.dart';
export 'src/dom/custom_state_pseudo_class.dart';
export 'src/dom/datacue.dart';
export 'src/dom/deprecation_reporting.dart';
export 'src/dom/device_memory.dart';
export 'src/dom/device_posture.dart';
export 'src/dom/digital_goods.dart';
export 'src/dom/dom.dart';
export 'src/dom/dom_parsing.dart';
export 'src/dom/edit_context.dart';
export 'src/dom/element_timing.dart';
export 'src/dom/encoding.dart';
export 'src/dom/encrypted_media.dart';
export 'src/dom/entries_api.dart';
export 'src/dom/event_timing.dart';
export 'src/dom/ext_blend_minmax.dart';
export 'src/dom/ext_color_buffer_float.dart';
export 'src/dom/ext_color_buffer_half_float.dart';
export 'src/dom/ext_disjoint_timer_query.dart';
export 'src/dom/ext_disjoint_timer_query_webgl2.dart';
export 'src/dom/ext_float_blend.dart';
export 'src/dom/ext_frag_depth.dart';
export 'src/dom/ext_shader_texture_lod.dart';
export 'src/dom/ext_srgb.dart';
export 'src/dom/ext_texture_compression_bptc.dart';
export 'src/dom/ext_texture_compression_rgtc.dart';
export 'src/dom/ext_texture_filter_anisotropic.dart';
export 'src/dom/ext_texture_norm16.dart';
export 'src/dom/eyedropper_api.dart';
export 'src/dom/fedcm.dart';
export 'src/dom/fenced_frame.dart';
export 'src/dom/fetch.dart';
export 'src/dom/fido.dart';
export 'src/dom/file_system_access.dart';
export 'src/dom/fileapi.dart';
export 'src/dom/filter_effects.dart';
export 'src/dom/font_metrics_api.dart';
export 'src/dom/fs.dart';
export 'src/dom/fullscreen.dart';
export 'src/dom/gamepad.dart';
export 'src/dom/gamepad_extensions.dart';
export 'src/dom/generic_sensor.dart';
export 'src/dom/geolocation.dart';
export 'src/dom/geolocation_sensor.dart';
export 'src/dom/geometry.dart';
export 'src/dom/get_installed_related_apps.dart';
export 'src/dom/gpc_spec.dart';
export 'src/dom/gyroscope.dart';
export 'src/dom/hr_time.dart';
export 'src/dom/html.dart';
export 'src/dom/html_media_capture.dart';
export 'src/dom/idle_detection.dart';
export 'src/dom/image_capture.dart';
export 'src/dom/image_resource.dart';
export 'src/dom/indexeddb.dart';
export 'src/dom/ink_enhancement.dart';
export 'src/dom/input_device_capabilities.dart';
export 'src/dom/input_events.dart';
export 'src/dom/intersection_observer.dart';
export 'src/dom/intervention_reporting.dart';
export 'src/dom/is_input_pending.dart';
export 'src/dom/js_self_profiling.dart';
export 'src/dom/keyboard_lock.dart';
export 'src/dom/keyboard_map.dart';
export 'src/dom/khr_parallel_shader_compile.dart';
export 'src/dom/largest_contentful_paint.dart';
export 'src/dom/layout_instability.dart';
export 'src/dom/local_font_access.dart';
export 'src/dom/longtasks.dart';
export 'src/dom/magnetometer.dart';
export 'src/dom/manifest_incubations.dart';
export 'src/dom/mathml_core.dart';
export 'src/dom/media_capabilities.dart';
export 'src/dom/media_playback_quality.dart';
export 'src/dom/media_source.dart';
export 'src/dom/mediacapture_automation.dart';
export 'src/dom/mediacapture_fromelement.dart';
export 'src/dom/mediacapture_handle_actions.dart';
export 'src/dom/mediacapture_region.dart';
export 'src/dom/mediacapture_streams.dart';
export 'src/dom/mediacapture_transform.dart';
export 'src/dom/mediacapture_viewport.dart';
export 'src/dom/mediasession.dart';
export 'src/dom/mediastream_recording.dart';
export 'src/dom/model_element.dart';
export 'src/dom/mst_content_hint.dart';
export 'src/dom/navigation_timing.dart';
export 'src/dom/netinfo.dart';
export 'src/dom/notifications.dart';
export 'src/dom/oes_draw_buffers_indexed.dart';
export 'src/dom/oes_element_index_uint.dart';
export 'src/dom/oes_fbo_render_mipmap.dart';
export 'src/dom/oes_standard_derivatives.dart';
export 'src/dom/oes_texture_float.dart';
export 'src/dom/oes_texture_float_linear.dart';
export 'src/dom/oes_texture_half_float.dart';
export 'src/dom/oes_texture_half_float_linear.dart';
export 'src/dom/oes_vertex_array_object.dart';
export 'src/dom/orientation_event.dart';
export 'src/dom/orientation_sensor.dart';
export 'src/dom/ovr_multiview2.dart';
export 'src/dom/page_lifecycle.dart';
export 'src/dom/paint_timing.dart';
export 'src/dom/payment_handler.dart';
export 'src/dom/payment_request.dart';
export 'src/dom/performance_measure_memory.dart';
export 'src/dom/performance_timeline.dart';
export 'src/dom/periodic_background_sync.dart';
export 'src/dom/permissions.dart';
export 'src/dom/permissions_policy.dart';
export 'src/dom/permissions_request.dart';
export 'src/dom/permissions_revoke.dart';
export 'src/dom/picture_in_picture.dart';
export 'src/dom/pointerevents.dart';
export 'src/dom/pointerlock.dart';
export 'src/dom/portals.dart';
export 'src/dom/prefer_current_tab.dart';
export 'src/dom/prerendering_revamped.dart';
export 'src/dom/presentation_api.dart';
export 'src/dom/private_click_measurement.dart';
export 'src/dom/proximity.dart';
export 'src/dom/push_api.dart';
export 'src/dom/raw_camera_access.dart';
export 'src/dom/referrer_policy.dart';
export 'src/dom/remote_playback.dart';
export 'src/dom/reporting.dart';
export 'src/dom/requestidlecallback.dart';
export 'src/dom/requeststorageaccessfor.dart';
export 'src/dom/resize_observer.dart';
export 'src/dom/resource_timing.dart';
export 'src/dom/sanitizer_api.dart';
export 'src/dom/savedata.dart';
export 'src/dom/scheduling_apis.dart';
export 'src/dom/screen_capture.dart';
export 'src/dom/screen_orientation.dart';
export 'src/dom/screen_wake_lock.dart';
export 'src/dom/scroll_animations.dart';
export 'src/dom/scroll_to_text_fragment.dart';
export 'src/dom/secure_payment_confirmation.dart';
export 'src/dom/selection_api.dart';
export 'src/dom/serial.dart';
export 'src/dom/server_timing.dart';
export 'src/dom/service_workers.dart';
export 'src/dom/shape_detection_api.dart';
export 'src/dom/speech_api.dart';
export 'src/dom/storage.dart';
export 'src/dom/storage_access.dart';
export 'src/dom/streams.dart';
export 'src/dom/svg.dart';
export 'src/dom/svg_animations.dart';
export 'src/dom/testutils.dart';
export 'src/dom/text_detection_api.dart';
export 'src/dom/touch_events.dart';
export 'src/dom/trust_token_api.dart';
export 'src/dom/trusted_types.dart';
export 'src/dom/turtledove.dart';
export 'src/dom/ua_client_hints.dart';
export 'src/dom/uievents.dart';
export 'src/dom/url.dart';
export 'src/dom/urlpattern.dart';
export 'src/dom/user_timing.dart';
export 'src/dom/vibration.dart';
export 'src/dom/video_rvfc.dart';
export 'src/dom/virtual_keyboard.dart';
export 'src/dom/wai_aria.dart';
export 'src/dom/wasm_js_api.dart';
export 'src/dom/wasm_web_api.dart';
export 'src/dom/web_animations.dart';
export 'src/dom/web_animations_2.dart';
export 'src/dom/web_app_launch.dart';
export 'src/dom/web_bluetooth.dart';
export 'src/dom/web_locks.dart';
export 'src/dom/web_nfc.dart';
export 'src/dom/web_otp.dart';
export 'src/dom/web_share.dart';
export 'src/dom/webaudio.dart';
export 'src/dom/webauthn.dart';
export 'src/dom/webcodecs.dart';
export 'src/dom/webcodecs_aac_codec_registration.dart';
export 'src/dom/webcodecs_av1_codec_registration.dart';
export 'src/dom/webcodecs_avc_codec_registration.dart';
export 'src/dom/webcodecs_flac_codec_registration.dart';
export 'src/dom/webcodecs_hevc_codec_registration.dart';
export 'src/dom/webcodecs_opus_codec_registration.dart';
export 'src/dom/webcodecs_vp9_codec_registration.dart';
export 'src/dom/webcrypto_secure_curves.dart';
export 'src/dom/webcryptoapi.dart';
export 'src/dom/webdriver.dart';
export 'src/dom/webgl1.dart';
export 'src/dom/webgl2.dart';
export 'src/dom/webgl_blend_equation_advanced_coherent.dart';
export 'src/dom/webgl_clip_cull_distance.dart';
export 'src/dom/webgl_color_buffer_float.dart';
export 'src/dom/webgl_compressed_texture_astc.dart';
export 'src/dom/webgl_compressed_texture_etc.dart';
export 'src/dom/webgl_compressed_texture_etc1.dart';
export 'src/dom/webgl_compressed_texture_pvrtc.dart';
export 'src/dom/webgl_compressed_texture_s3tc.dart';
export 'src/dom/webgl_compressed_texture_s3tc_srgb.dart';
export 'src/dom/webgl_debug_renderer_info.dart';
export 'src/dom/webgl_debug_shaders.dart';
export 'src/dom/webgl_depth_texture.dart';
export 'src/dom/webgl_draw_buffers.dart';
export 'src/dom/webgl_draw_instanced_base_vertex_base_instance.dart';
export 'src/dom/webgl_lose_context.dart';
export 'src/dom/webgl_multi_draw.dart';
export 'src/dom/webgl_multi_draw_instanced_base_vertex_base_instance.dart';
export 'src/dom/webgl_provoking_vertex.dart';
export 'src/dom/webgpu.dart';
export 'src/dom/webhid.dart';
export 'src/dom/webidl.dart';
export 'src/dom/webmidi.dart';
export 'src/dom/webnn.dart';
export 'src/dom/webrtc.dart';
export 'src/dom/webrtc_encoded_transform.dart';
export 'src/dom/webrtc_ice.dart';
export 'src/dom/webrtc_identity.dart';
export 'src/dom/webrtc_priority.dart';
export 'src/dom/webrtc_stats.dart';
export 'src/dom/webrtc_svc.dart';
export 'src/dom/websockets.dart';
export 'src/dom/webtransport.dart';
export 'src/dom/webusb.dart';
export 'src/dom/webvtt.dart';
export 'src/dom/webxr.dart';
export 'src/dom/webxr_ar_module.dart';
export 'src/dom/webxr_depth_sensing.dart';
export 'src/dom/webxr_dom_overlays.dart';
export 'src/dom/webxr_gamepads_module.dart';
export 'src/dom/webxr_hand_input.dart';
export 'src/dom/webxr_hit_test.dart';
export 'src/dom/webxr_lighting_estimation.dart';
export 'src/dom/webxrlayers.dart';
export 'src/dom/window_controls_overlay.dart';
export 'src/dom/window_management.dart';
export 'src/dom/xhr.dart';

==> 0.2.2-beta.tar.gz: lib/web.dart <==
// Copyright (c) 2023, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

export 'src/dom/accelerometer.dart';
export 'src/dom/ambient_light.dart';
export 'src/dom/anchors.dart';
export 'src/dom/angle_instanced_arrays.dart';
export 'src/dom/attribution_reporting_api.dart';
export 'src/dom/audio_output.dart';
export 'src/dom/autoplay_detection.dart';
export 'src/dom/background_fetch.dart';
export 'src/dom/background_sync.dart';
export 'src/dom/badging.dart';
export 'src/dom/battery_status.dart';
export 'src/dom/beacon.dart';
export 'src/dom/capture_handle_identity.dart';
export 'src/dom/captured_mouse_events.dart';
export 'src/dom/clipboard_apis.dart';
export 'src/dom/compat.dart';
export 'src/dom/compression.dart';
export 'src/dom/compute_pressure.dart';
export 'src/dom/console.dart';
export 'src/dom/contact_picker.dart';
export 'src/dom/content_index.dart';
export 'src/dom/cookie_store.dart';
export 'src/dom/crash_reporting.dart';
export 'src/dom/credential_management.dart';
export 'src/dom/csp.dart';
export 'src/dom/csp_embedded_enforcement.dart';
export 'src/dom/csp_next.dart';
export 'src/dom/css_anchor_position.dart';
export 'src/dom/css_animation_worklet.dart';
export 'src/dom/css_animations.dart';
export 'src/dom/css_animations_2.dart';
export 'src/dom/css_cascade.dart';
export 'src/dom/css_cascade_6.dart';
export 'src/dom/css_color_5.dart';
export 'src/dom/css_conditional.dart';
export 'src/dom/css_contain.dart';
export 'src/dom/css_contain_3.dart';
export 'src/dom/css_counter_styles.dart';
export 'src/dom/css_font_loading.dart';
export 'src/dom/css_fonts.dart';
export 'src/dom/css_highlight_api.dart';
export 'src/dom/css_images_4.dart';
export 'src/dom/css_layout_api.dart';
export 'src/dom/css_masking.dart';
export 'src/dom/css_nav.dart';
export 'src/dom/css_paint_api.dart';
export 'src/dom/css_parser_api.dart';
export 'src/dom/css_properties_values_api.dart';
export 'src/dom/css_pseudo.dart';
export 'src/dom/css_regions.dart';
export 'src/dom/css_shadow_parts.dart';
export 'src/dom/css_transitions.dart';
export 'src/dom/css_transitions_2.dart';
export 'src/dom/css_typed_om.dart';
export 'src/dom/css_view_transitions.dart';
export 'src/dom/cssom.dart';
export 'src/dom/cssom_view.dart';
export 'src/dom/custom_state_pseudo_class.dart';
export 'src/dom/datacue.dart';
export 'src/dom/deprecation_reporting.dart';
export 'src/dom/device_memory.dart';
export 'src/dom/device_posture.dart';
export 'src/dom/digital_goods.dart';
export 'src/dom/document_picture_in_picture.dart';
export 'src/dom/dom.dart';
export 'src/dom/dom_parsing.dart';
export 'src/dom/edit_context.dart';
export 'src/dom/element_capture.dart';
export 'src/dom/element_timing.dart';
export 'src/dom/encoding.dart';
export 'src/dom/encrypted_media.dart';
export 'src/dom/entries_api.dart';
export 'src/dom/event_timing.dart';
export 'src/dom/ext_blend_minmax.dart';
export 'src/dom/ext_color_buffer_float.dart';
export 'src/dom/ext_color_buffer_half_float.dart';
export 'src/dom/ext_disjoint_timer_query.dart';
export 'src/dom/ext_disjoint_timer_query_webgl2.dart';
export 'src/dom/ext_float_blend.dart';
export 'src/dom/ext_frag_depth.dart';
export 'src/dom/ext_shader_texture_lod.dart';
export 'src/dom/ext_srgb.dart';
export 'src/dom/ext_texture_compression_bptc.dart';
export 'src/dom/ext_texture_compression_rgtc.dart';
export 'src/dom/ext_texture_filter_anisotropic.dart';
export 'src/dom/ext_texture_norm16.dart';
export 'src/dom/eyedropper_api.dart';
export 'src/dom/fedcm.dart';
export 'src/dom/fenced_frame.dart';
export 'src/dom/fetch.dart';
export 'src/dom/fido.dart';
export 'src/dom/file_system_access.dart';
export 'src/dom/fileapi.dart';
export 'src/dom/filter_effects.dart';
export 'src/dom/font_metrics_api.dart';
export 'src/dom/fs.dart';
export 'src/dom/fullscreen.dart';
export 'src/dom/gamepad.dart';
export 'src/dom/gamepad_extensions.dart';
export 'src/dom/generic_sensor.dart';
export 'src/dom/geolocation.dart';
export 'src/dom/geolocation_sensor.dart';
export 'src/dom/geometry.dart';
export 'src/dom/get_installed_related_apps.dart';
export 'src/dom/gyroscope.dart';
export 'src/dom/hr_time.dart';
export 'src/dom/html.dart';
export 'src/dom/html_media_capture.dart';
export 'src/dom/idle_detection.dart';
export 'src/dom/image_capture.dart';
export 'src/dom/image_resource.dart';
export 'src/dom/indexeddb.dart';
export 'src/dom/ink_enhancement.dart';
export 'src/dom/input_device_capabilities.dart';
export 'src/dom/input_events.dart';
export 'src/dom/intersection_observer.dart';
export 'src/dom/intervention_reporting.dart';
export 'src/dom/is_input_pending.dart';
export 'src/dom/js_self_profiling.dart';
export 'src/dom/keyboard_lock.dart';
export 'src/dom/keyboard_map.dart';
export 'src/dom/khr_parallel_shader_compile.dart';
export 'src/dom/largest_contentful_paint.dart';
export 'src/dom/layout_instability.dart';
export 'src/dom/local_font_access.dart';
export 'src/dom/longtasks.dart';
export 'src/dom/magnetometer.dart';
export 'src/dom/manifest_incubations.dart';
export 'src/dom/mathml_core.dart';
export 'src/dom/media_capabilities.dart';
export 'src/dom/media_playback_quality.dart';
export 'src/dom/media_source.dart';
export 'src/dom/mediacapture_automation.dart';
export 'src/dom/mediacapture_fromelement.dart';
export 'src/dom/mediacapture_handle_actions.dart';
export 'src/dom/mediacapture_region.dart';
export 'src/dom/mediacapture_streams.dart';
export 'src/dom/mediacapture_transform.dart';
export 'src/dom/mediacapture_viewport.dart';
export 'src/dom/mediasession.dart';
export 'src/dom/mediastream_recording.dart';
export 'src/dom/model_element.dart';
export 'src/dom/mst_content_hint.dart';
export 'src/dom/navigation_timing.dart';
export 'src/dom/netinfo.dart';
export 'src/dom/notifications.dart';
export 'src/dom/oes_draw_buffers_indexed.dart';
export 'src/dom/oes_element_index_uint.dart';
export 'src/dom/oes_fbo_render_mipmap.dart';
export 'src/dom/oes_standard_derivatives.dart';
export 'src/dom/oes_texture_float.dart';
export 'src/dom/oes_texture_float_linear.dart';
export 'src/dom/oes_texture_half_float.dart';
export 'src/dom/oes_texture_half_float_linear.dart';
export 'src/dom/oes_vertex_array_object.dart';
export 'src/dom/orientation_event.dart';
export 'src/dom/orientation_sensor.dart';
export 'src/dom/ovr_multiview2.dart';
export 'src/dom/page_lifecycle.dart';
export 'src/dom/paint_timing.dart';
export 'src/dom/payment_handler.dart';
export 'src/dom/payment_request.dart';
export 'src/dom/performance_measure_memory.dart';
export 'src/dom/performance_timeline.dart';
export 'src/dom/periodic_background_sync.dart';
export 'src/dom/permissions.dart';
export 'src/dom/permissions_policy.dart';
export 'src/dom/permissions_request.dart';
export 'src/dom/permissions_revoke.dart';
export 'src/dom/picture_in_picture.dart';
export 'src/dom/pointerevents.dart';
export 'src/dom/pointerlock.dart';
export 'src/dom/portals.dart';
export 'src/dom/prefer_current_tab.dart';
export 'src/dom/prerendering_revamped.dart';
export 'src/dom/presentation_api.dart';
export 'src/dom/private_click_measurement.dart';
export 'src/dom/private_network_access.dart';
export 'src/dom/proximity.dart';
export 'src/dom/push_api.dart';
export 'src/dom/raw_camera_access.dart';
export 'src/dom/real_world_meshing.dart';
export 'src/dom/referrer_policy.dart';
export 'src/dom/remote_playback.dart';
export 'src/dom/reporting.dart';
export 'src/dom/requestidlecallback.dart';
export 'src/dom/requeststorageaccessfor.dart';
export 'src/dom/resize_observer.dart';
export 'src/dom/resource_timing.dart';
export 'src/dom/sanitizer_api.dart';
export 'src/dom/savedata.dart';
export 'src/dom/scheduling_apis.dart';
export 'src/dom/screen_capture.dart';
export 'src/dom/screen_orientation.dart';
export 'src/dom/screen_wake_lock.dart';
export 'src/dom/scroll_animations.dart';
export 'src/dom/scroll_to_text_fragment.dart';
export 'src/dom/secure_payment_confirmation.dart';
export 'src/dom/selection_api.dart';
export 'src/dom/serial.dart';
export 'src/dom/server_timing.dart';
export 'src/dom/service_workers.dart';
export 'src/dom/shape_detection_api.dart';
export 'src/dom/shared_storage.dart';
export 'src/dom/speech_api.dart';
export 'src/dom/storage.dart';
export 'src/dom/storage_access.dart';
export 'src/dom/storage_buckets.dart';
export 'src/dom/streams.dart';
export 'src/dom/svg.dart';
export 'src/dom/svg_animations.dart';
export 'src/dom/testutils.dart';
export 'src/dom/text_detection_api.dart';
export 'src/dom/touch_events.dart';
export 'src/dom/trust_token_api.dart';
export 'src/dom/trusted_types.dart';
export 'src/dom/turtledove.dart';
export 'src/dom/ua_client_hints.dart';
export 'src/dom/uievents.dart';
export 'src/dom/url.dart';
export 'src/dom/urlpattern.dart';
export 'src/dom/user_timing.dart';
export 'src/dom/vibration.dart';
export 'src/dom/video_rvfc.dart';
export 'src/dom/virtual_keyboard.dart';
export 'src/dom/wai_aria.dart';
export 'src/dom/wasm_js_api.dart';
export 'src/dom/wasm_web_api.dart';
export 'src/dom/web_animations.dart';
export 'src/dom/web_animations_2.dart';
export 'src/dom/web_app_launch.dart';
export 'src/dom/web_bluetooth.dart';
export 'src/dom/web_locks.dart';
export 'src/dom/web_nfc.dart';
export 'src/dom/web_otp.dart';
export 'src/dom/web_share.dart';
export 'src/dom/webaudio.dart';
export 'src/dom/webauthn.dart';
export 'src/dom/webcodecs.dart';
export 'src/dom/webcodecs_aac_codec_registration.dart';
export 'src/dom/webcodecs_av1_codec_registration.dart';
export 'src/dom/webcodecs_avc_codec_registration.dart';
export 'src/dom/webcodecs_flac_codec_registration.dart';
export 'src/dom/webcodecs_hevc_codec_registration.dart';
export 'src/dom/webcodecs_opus_codec_registration.dart';
export 'src/dom/webcodecs_vp9_codec_registration.dart';
export 'src/dom/webcrypto_secure_curves.dart';
export 'src/dom/webcryptoapi.dart';
export 'src/dom/webdriver.dart';
export 'src/dom/webgl1.dart';
export 'src/dom/webgl2.dart';
export 'src/dom/webgl_blend_equation_advanced_coherent.dart';
export 'src/dom/webgl_clip_cull_distance.dart';
export 'src/dom/webgl_color_buffer_float.dart';
export 'src/dom/webgl_compressed_texture_astc.dart';
export 'src/dom/webgl_compressed_texture_etc.dart';
export 'src/dom/webgl_compressed_texture_etc1.dart';
export 'src/dom/webgl_compressed_texture_pvrtc.dart';
export 'src/dom/webgl_compressed_texture_s3tc.dart';
export 'src/dom/webgl_compressed_texture_s3tc_srgb.dart';
export 'src/dom/webgl_debug_renderer_info.dart';
export 'src/dom/webgl_debug_shaders.dart';
export 'src/dom/webgl_depth_texture.dart';
export 'src/dom/webgl_draw_buffers.dart';
export 'src/dom/webgl_draw_instanced_base_vertex_base_instance.dart';
export 'src/dom/webgl_lose_context.dart';
export 'src/dom/webgl_multi_draw.dart';
export 'src/dom/webgl_multi_draw_instanced_base_vertex_base_instance.dart';
export 'src/dom/webgl_provoking_vertex.dart';
export 'src/dom/webgpu.dart';
export 'src/dom/webhid.dart';
export 'src/dom/webidl.dart';
export 'src/dom/webmidi.dart';
export 'src/dom/webnn.dart';
export 'src/dom/webrtc.dart';
export 'src/dom/webrtc_encoded_transform.dart';
export 'src/dom/webrtc_ice.dart';
export 'src/dom/webrtc_identity.dart';
export 'src/dom/webrtc_priority.dart';
export 'src/dom/webrtc_stats.dart';
export 'src/dom/webrtc_svc.dart';
export 'src/dom/websockets.dart';
export 'src/dom/webtransport.dart';
export 'src/dom/webusb.dart';
export 'src/dom/webvtt.dart';
export 'src/dom/webxr.dart';
export 'src/dom/webxr_ar_module.dart';
export 'src/dom/webxr_depth_sensing.dart';
export 'src/dom/webxr_dom_overlays.dart';
export 'src/dom/webxr_gamepads_module.dart';
export 'src/dom/webxr_hand_input.dart';
export 'src/dom/webxr_hit_test.dart';
export 'src/dom/webxr_lighting_estimation.dart';
export 'src/dom/webxrlayers.dart';
export 'src/dom/window_controls_overlay.dart';
export 'src/dom/window_management.dart';
export 'src/dom/xhr.dart';
